### Multinomial Logit model estimation

###AGE PARAMETER------

### Create the data array from the existing dataset
Data <- read.csv("Data_Clean_English.csv",header=TRUE)

Data<-subset(Data,Data$ODDistanceM<=5000)
write.csv(Data,"Under5000.csv")

Data2 <- read.csv("Under5000.csv")
DataF <- subset(Data2,Data2$Gender=="Female")
DataM <- subset(Data2,Data2$Gender=="Male")
write.csv(DataF,"DataFemale.csv")
write.csv(DataM,"DataMale.csv")

Data3 <- read.csv("Data_NEW.csv")
Data3 <- subset(Data3,Data3$ODDistanceM<=5000)
write.csv(Data3,"Data3.csv")
DataM <- subset(Data3,Data3$Male=="1")
DataF <- subset(Data3,Data3$Male=="0")
write.csv(DataF,"DataFemaleNEW.csv")
write.csv(DataM,"DataMaleNEW.csv")



###for ALL-----

Data <- read.csv("Under5000.csv",header=TRUE)

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(9)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age paraneter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100+c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1))
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100+c2*Data$Age   +b2*matrix(1,nrow =hh,ncol=1))
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100+c3*Data$Age         +b3*matrix(1,nrow =hh,ncol=1))
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100+c4*Data$Age        +b4*matrix(1,nrow =hh,ncol=1))
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)



###for FEMALE
Data<-read.csv("DataFemale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(9)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age paraneter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100+c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1))
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100+c2*Data$Age   +b2*matrix(1,nrow =hh,ncol=1))
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100+c3*Data$Age         +b3*matrix(1,nrow =hh,ncol=1))
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100+c4*Data$Age        +b4*matrix(1,nrow =hh,ncol=1))
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)





###for MALE--
Data<-read.csv("DataMale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(9)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age paraneter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100+c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1))
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100+c2*Data$Age   +b2*matrix(1,nrow =hh,ncol=1))
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100+c3*Data$Age         +b3*matrix(1,nrow =hh,ncol=1))
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100+c4*Data$Age        +b4*matrix(1,nrow =hh,ncol=1))
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)






###add Purpose---

###for ALL
Data<-read.csv("Under5000.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(13)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age parameter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## Purpose parameter
  e1 <- x[10]
  e2 <- x[11]
  e3 <- x[12]
  e4 <- x[13]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100 +c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1)  +e1*Data$Purpose)
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100   +c2*Data$Age  +b2*matrix(1,nrow =hh,ncol=1)  +e2*Data$Purpose)
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100        +c3*Data$Age  +b3*matrix(1,nrow =hh,ncol=1)  +e3*Data$Purpose)
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100       +c4*Data$Age  +b4*matrix(1,nrow =hh,ncol=1)  +e4*Data$Purpose)
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)



###for FEMALE
Data<-read.csv("DataFemale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(13)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age parameter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## Purpose parameter
  e1 <- x[10]
  e2 <- x[11]
  e3 <- x[12]
  e4 <- x[13]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100 +c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1)  +e1*Data$Purpose)
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100   +c2*Data$Age  +b2*matrix(1,nrow =hh,ncol=1)  +e2*Data$Purpose)
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100        +c3*Data$Age  +b3*matrix(1,nrow =hh,ncol=1)  +e3*Data$Purpose)
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100       +c4*Data$Age  +b4*matrix(1,nrow =hh,ncol=1)  +e4*Data$Purpose)
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)





###for MALE
Data<-read.csv("DataMale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(13)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age parameter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## Purpose parameter
  e1 <- x[10]
  e2 <- x[11]
  e3 <- x[12]
  e4 <- x[13]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100 +c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1)  +e1*Data$Purpose)
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100   +c2*Data$Age  +b2*matrix(1,nrow =hh,ncol=1)  +e2*Data$Purpose)
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100        +c3*Data$Age  +b3*matrix(1,nrow =hh,ncol=1)  +e3*Data$Purpose)
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100       +c4*Data$Age  +b4*matrix(1,nrow =hh,ncol=1)  +e4*Data$Purpose)
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)



### LC


###for FEMALE
Data<-read.csv("DataFemale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(4)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  #d1 <- x[5]
  
  ## Age parameter
  #c1 <- x[6]
  #c2 <- x[7]
  #c3 <- x[8]
  #c4 <- x[9]
  
  ## Purpose parameter
  #e1 <- x[10]
  #e2 <- x[11]
  #e3 <- x[12]
  #e4 <- x[13]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(b1*matrix(1,nrow =hh,ncol=1))
  bus    <- Data$ModeAvailableBus  *exp(b2*matrix(1,nrow =hh,ncol=1))
  car    <- Data$ModeAvailableCar  *exp(b3*matrix(1,nrow =hh,ncol=1))
  bike   <- Data$ModeAvailableBike *exp(b4*matrix(1,nrow =hh,ncol=1))
  walk   <- Data$ModeAvailableWalk 
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)



###for MALE
Data<-read.csv("DataMale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(4)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  #d1 <- x[5]
  
  ## Age parameter
  #c1 <- x[6]
  #c2 <- x[7]
  #c3 <- x[8]
  #c4 <- x[9]
  
  ## Purpose parameter
  #e1 <- x[10]
  #e2 <- x[11]
  #e3 <- x[12]
  #e4 <- x[13]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(b1*matrix(1,nrow =hh,ncol=1))
  bus    <- Data$ModeAvailableBus  *exp(b2*matrix(1,nrow =hh,ncol=1))
  car    <- Data$ModeAvailableCar  *exp(b3*matrix(1,nrow =hh,ncol=1))
  bike   <- Data$ModeAvailableBike *exp(b4*matrix(1,nrow =hh,ncol=1))
  walk   <- Data$ModeAvailableWalk 
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)




###add Purpose and Trip Duration



###for FEMALE
Data<-read.csv("DataFemale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(17)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age parameter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## Purpose parameter
  e1 <- x[10]
  e2 <- x[11]
  e3 <- x[12]
  e4 <- x[13]
  
  ## Purpose parameter
  g1 <- x[14]
  g2 <- x[15]
  g3 <- x[16]
  g4 <- x[17]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100 +c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1)  +e1*Data$Purpose   +g1*Data$TripDurationSec)
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100   +c2*Data$Age  +b2*matrix(1,nrow =hh,ncol=1)  +e2*Data$Purpose   +g2*Data$TripDurationSec)
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100        +c3*Data$Age  +b3*matrix(1,nrow =hh,ncol=1)  +e3*Data$Purpose   +g3*Data$TripDurationSec)
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100       +c4*Data$Age  +b4*matrix(1,nrow =hh,ncol=1)  +e4*Data$Purpose   +g4*Data$TripDurationSec)
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)





###for MALE
Data<-read.csv("DataMale2.csv")

## Count the number of data rows
hh <- nrow(Data)

## Set the initial values of the parameters (the number in parenthesis corresponds to the number of parameters to be estimated)
b0 <- numeric(13)

## Recall that we estimate parameters by maximizing the log-likelihood function, hence we first need to define that function

##### Define the log-likelihood function of the logit model#####

fr <- function(x) {
  ### declare the parameters###
  ## Alternative specific constants
  b1 <- x[1]
  b2 <- x[2]
  b3 <- x[3]
  b4 <- x[4]
  
  ## Travel time to destination
  d1 <- x[5]
  
  ## Age parameter
  c1 <- x[6]
  c2 <- x[7]
  c3 <- x[8]
  c4 <- x[9]
  
  ## Purpose parameter
  e1 <- x[10]
  e2 <- x[11]
  e3 <- x[12]
  e4 <- x[13]
  
  ## declare the log-likelihood variable, set value to 0
  LL = 0
  
  ### For this choice problem, we consider the following 5 modes???
  ## ??(train)
  ## バス(bus)
  ## 自動?(car)
  ## 自転?(bike)
  ## 徒歩(walk)
  
  ## calculate the utility function: :introduce the desired explanatory variables in the function
  # time           # fare      # constant
  train  <- Data$ModeAvailableTrain*exp(d1*Data$TotalTimeTrain/100 +c1*Data$Age  +b1*matrix(1,nrow =hh,ncol=1)  +e1*Data$Purpose   +g1*Data$TripDurationSec)
  bus    <- Data$ModeAvailableBus  *exp(d1*Data$TotalTimeBus/100   +c2*Data$Age  +b2*matrix(1,nrow =hh,ncol=1)  +e2*Data$Purpose   +g2*Data$TripDurationSec)
  car    <- Data$ModeAvailableCar  *exp(d1*Data$TimeCar/100        +c3*Data$Age  +b3*matrix(1,nrow =hh,ncol=1)  +e3*Data$Purpose   +g3*Data$TripDurationSec)
  bike   <- Data$ModeAvailableBike *exp(d1*Data$TimeBike/100       +c4*Data$Age  +b4*matrix(1,nrow =hh,ncol=1)  +e4*Data$Purpose   +g4*Data$TripDurationSec)
  walk   <- Data$ModeAvailableWalk *exp(d1*Data$TimeWalk/100                                                 )
  
  ### Calculate the choice probabilities
  ## calculate the Inclusive Value (the denominator of the choice probabilities equation)
  deno <- (car + train + bus + bike + walk)
  
  ## Calculate indiviudal choice probabilities
  Ptrain <- Data$ModeAvailableTrain*(train / deno)
  Pbus   <- Data$ModeAvailableTrain  *(bus   / deno)
  Pcar   <- Data$ModeAvailableCar  *(car   / deno)
  Pbike  <- Data$ModeAvailableBike *(bike  / deno)
  Pwalk  <- Data$ModeAvailableWalk *(walk  / deno)
  
  ## Avoid problems stemming from choice probabilities becoming zero.選択確??????0になってしまっ????合に起こる問????回避
  Ptrain <- (Ptrain!=0)*Ptrain + (Ptrain==0)
  Pbus   <- (Pbus!=0)*Pbus     + (Pbus==0)
  Pcar   <- (Pcar  !=0)*Pcar   + (Pcar  ==0)
  Pbike  <- (Pbike  !=0)*Pbike + (Pbike  ==0)
  Pwalk  <- (Pwalk!=0)*Pwalk   + (Pwalk  ==0)
  
  
  
  ## Choice results
  Ctrain   <- Data$MainModeENG =="Rail"
  Cbus     <- Data$MainModeENG =="Bus"
  Ccar     <- Data$MainModeENG =="Car"
  Cbike    <- Data$MainModeENG =="Bicycle"
  Cwalk    <- Data$MainModeENG =="Walk"
  
  ## Calculate the Log-likelihood function
  LL <- colSums(Ctrain*log(Ptrain) + Cbus*log(Pbus) +
                  Ccar  *log(Pcar)   + Cbike  *log(Pbike) +Cwalk *log(Pwalk))
  
}

##### Maximize the Log-likelihood function#####

##Parameter optimization 
res <- optim(b0,fr,gr=NULL, method = "Nelder-Mead", hessian = TRUE, control=list(fnscale=-1))

## Parmeter estimation、Hessian matrix calculation 
b   <- res$par
hhh <- res$hessian

## Calculate the t-statistic
tval <- b/sqrt(-diag(solve(hhh)))

## L(0), Log-Likelihood when all parameters are 0
L0 <- fr(b0)
## LL, maximium likelihood
LL <- res$value

##### Output #####
print(res)
## L(0)
print(L0)
## LL
print(LL)
##rho-square
print((L0-LL)/L0)
## adjusted rho-square
print((L0-(LL-length(b)))/L0)
##estimated parameter values
print(b)
## t-statistic 
print(tval)